@@ -253,24 +253,24 @@ class Data:
     ld_samba_hash = {}
 
     # Директория настроек пользователя windows
-    sr_samba_winprof_path = {\
-                    'value':'/var/calculate/server-data/samba/profiles/win'}
+    sr_samba_winprof_path = \
+        {'value':'/var/calculate/server-data/samba/profiles/win'}
 
     # Директория хранения настроек пользователя linux
-    sr_samba_linprof_path = {\
-                    'value':'/var/calculate/server-data/samba/profiles/unix'}
+    sr_samba_linprof_path = \
+        {'value':'/var/calculate/server-data/samba/profiles/unix'}
 
     # Домашняя директория
-    sr_samba_home_path = {\
-                    'value':'/var/calculate/server-data/samba/home'}
+    sr_samba_home_path = \
+        {'value':'/var/calculate/server-data/samba/home'}
 
     # Директория netlogon
-    sr_samba_winlogon_path = {\
-                    'value':'/var/calculate/server-data/samba/netlogon'}
+    sr_samba_winlogon_path = \
+        {'value':'/var/calculate/server-data/samba/netlogon'}
 
     # Директория share
-    sr_samba_share_path = {\
-                    'value':'/var/calculate/server-data/samba/share'}
+    sr_samba_share_path = \
+        {'value':'/var/calculate/server-data/samba/share'}
 
     # Настроен или нет сервис Samba
     sr_samba_set = {'mode':"w",
